@@ -49,7 +49,7 @@ runExample <- function(name=NULL,all=FALSE,thisR=TRUE,
     lapply(exnames,runExample,
            thisR=thisR,clean=clean,exfolder=exfolder,
            dontrun=dontrun,subarch=subarch,...)
-    return(NULL)
+    return(invisible(NULL))
   }
   if(is.null(name)){
     txt <- paste("Examples in " ,"\'",exfolder,"\':","\n\n",sep="")
